import os
import re
from datetime import datetime
import imageio
from PIL import Image
import numpy as np

# Define the start and end times
start_time = datetime(2024, 9, 15, 23, 30)
end_time = datetime(2024, 9, 16, 11, 30)

# Create a list to store the filtered file names
filtered_files = []

# Iterate over all files in the directory
for filename in os.listdir("."):
    # Check if the file is a .png file
    if filename.endswith(".png"):
        # Extract the date and time from the file name
        match = re.match(r".*_(\d{8})(\d{6})\.png", filename)
        if match:
            date_str = match.group(1)
            time_str = match.group(2)
            file_time = datetime(int(date_str[:4]), int(date_str[4:6]), int(date_str[6:8]), int(time_str[:2]), int(time_str[2:4]), int(time_str[4:6]))
            # Check if the file time is within the specified range
            if start_time <= file_time <= end_time:
                filtered_files.append((file_time, filename))

# Sort the filtered files by their timestamp
filtered_files.sort(key=lambda x: x[0])

# Create a list to store the images
images = []

# Iterate over the filtered files and read the images
for _, filename in filtered_files:
    img = Image.open(filename)
    img = img.resize((800, 800))  # Resize the image to a common resolution
    img = np.array(img)  # Convert the image to a numpy array
    images.append(img)

# Save the images as a GIF
imageio.mimsave('output.gif', images, 'GIF', duration=0.1)
